# Changelog

## [v0.4.0](https://github.com/hkato/markdown-kroki/releases/tag/v0.4.0) - 2025-04-30

### Added

- feat: Implement external file support as MkDocs plugin (Experimental)
- test: Add unit tests using pytest

### Changed

- refactor: Split Kroki server handling

## [v0.3.0](https://github.com/hkato/markdown-kroki/releases/tag/v0.3.0) - 2025-04-23

### Added

- Direct link support (GET API)
    - `img_src` option

## [v0.2.0](https://github.com/hkato/markdown-kroki/releases/tag/v0.2.0) - 2025-04-22

### Changed

- Image format option from 'image' to 'format'
- README: Install procedure from GitHub to PyPI

### Added

- Support [Diagram options](https://docs.kroki.io/kroki/setup/diagram-options/)

## [v0.1.0](https://github.com/hkato/markdown-kroki/releases/tag/v0.1.0) - 2025-04-20

Initial Release
